@@ -194,7 +194,7 @@ class DialogMirror:
     ''' Check if a given uri is a vaild one '''
     if uri == None:
         return False
-    elif re.match("^((ftp)|(http)|(file)|(rsync)|(https))://([a-z]|[A-Z]|[0-9]|:|/|\.|~)+$", uri) == None:
+    elif re.match(r"^((ftp)|(http)|(file)|(rsync)|(https))://([a-z]|[A-Z]|[0-9]|:|/|\.|~)+$", uri) == None:
         return False
     else:
         return True
