@@ -301,6 +301,11 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         # Make sure window is as small as possible initially.
         self.window_main.resize(1, 1)
 
+    def do_shutdown(self):
+        if self.search_process and self.search_process.is_alive():
+            self.search_process.terminate()
+        SimpleGtkbuilderApp.do_shutdown(self)
+
     def on_main_notebook_page_switched(self, notebook, page, page_num):
         # On the additional drivers page, don't show the backend revert button.
         if page == self.vbox_drivers or page == self.vbox_auth:
@@ -311,7 +316,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
     def maybe_detect_drivers(self):
         if not self.search_process or not self.search_process.is_alive():
-            t = threading.Thread(target=self.detect_drivers, daemon=True)
+            t = threading.Thread(target=self.detect_drivers)
             self.label_driver_detail.set_text(_("Searching for available drivers..."))
             t.start()
 
@@ -1395,7 +1400,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.search_process = Process(
             target=self.wrapper_system_device_drivers,
             args=(queue, self.apt_cache,),
-            daemon=True
         )
         self.search_process.start()
         GLib.idle_add(lambda: self.update_drivers_control_button())
